@@ -2,7 +2,7 @@ import os
 import json
 from pathlib import Path
 import click
-from ..context import get_default_gateway
+from ..context import get_default_gateway, get_default_net
 from ..python.commands import run_python_internal
 
 def _impl_adc_path() -> str:
@@ -10,15 +10,20 @@ def _impl_adc_path() -> str:
 
 @click.command(name="adc", help="Read voltage from ADC net")
 @click.pass_context
-@click.option("--gateway", required=False, hidden=True, help="DUT or Gateway IP")
-@click.option("--dut", required=False, help="DUT or Gateway IP")
-@click.argument("netname", required=True)
-def adc(ctx, gateway, dut, netname):
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
+@click.argument("netname", required=False)
+def adc(ctx, box, dut, netname):
+    # Use provided netname, or fall back to default if not provided
+    if netname is None:
+        netname = get_default_net(ctx, 'adc')
+        if netname is None:
+            raise click.UsageError("NETNAME required. Either provide it as an argument or set a default with: lager defaults add --adc-net <name>")
     from ..dut_storage import get_dut_ip
 
-    # Check if gateway is a local DUT name first
-    if gateway:
-        local_ip = get_dut_ip(gateway)
+    # Check if box is a local DUT name first
+    if box:
+        local_ip = get_dut_ip(box)
         if local_ip:
             gateway = local_ip
     elif dut:
@@ -36,7 +41,7 @@ def adc(ctx, gateway, dut, netname):
     run_python_internal(
         ctx=ctx,
         runnable=_impl_adc_path(),
-        gateway=gateway,
+        box=gateway,
         image=gateway_image,
         env=(),
         passenv=(),
