@@ -101,9 +101,142 @@ class DirectIPSession:
     Direct session for communicating with DUT IPs via SSH + docker exec
     """
 
-    def __init__(self, ip_address, *args, **kwargs):
+    def __init__(self, ip_address, dut_name=None, *args, **kwargs):
+        from .dut_storage import get_dut_user
+
         self.ip_address = ip_address
-        self.ssh_host = f'lagerdata@{ip_address}'
+
+        # Look up username from DUT storage if DUT name is provided
+        username = None
+        if dut_name:
+            username = get_dut_user(dut_name)
+
+        # Default to 'lagerdata' if no username found
+        if not username:
+            username = 'lagerdata'
+
+        self.ssh_host = f'{username}@{ip_address}'
+
+    def _create_streaming_response(self, process):
+        """Create a streaming mock response for a subprocess"""
+        class StreamingMockResponse:
+            def __init__(self, process):
+                self.process = process
+                self.headers = {'Lager-Output-Version': '1'}
+                self._returncode = None
+
+            def iter_content(self, chunk_size=1024):
+                """Stream output in real-time using v1 protocol format"""
+                import select
+                import os
+                import fcntl
+
+                # Set stdout and stderr to non-blocking mode
+                flags = fcntl.fcntl(self.process.stdout, fcntl.F_GETFL)
+                fcntl.fcntl(self.process.stdout, fcntl.F_SETFL, flags | os.O_NONBLOCK)
+                flags = fcntl.fcntl(self.process.stderr, fcntl.F_GETFL)
+                fcntl.fcntl(self.process.stderr, fcntl.F_SETFL, flags | os.O_NONBLOCK)
+
+                # Buffers for line-based output
+                stdout_buffer = b''
+                stderr_buffer = b''
+
+                def flush_buffer(buffer, fileno):
+                    """Yield a buffer as a protocol message"""
+                    if buffer:
+                        header = f"{fileno} {len(buffer)} ".encode()
+                        for byte in header:
+                            yield bytes([byte])
+                        for byte in buffer:
+                            yield bytes([byte])
+
+                # Stream output until process completes
+                while True:
+                    # Check if process has terminated
+                    poll_result = self.process.poll()
+
+                    # Use select to wait for data with timeout
+                    readable, _, _ = select.select(
+                        [self.process.stdout, self.process.stderr],
+                        [], [],
+                        0.1  # 100ms timeout
+                    )
+
+                    # Read from stdout if available
+                    if self.process.stdout in readable:
+                        try:
+                            chunk = self.process.stdout.read(chunk_size)
+                            if chunk:
+                                stdout_buffer += chunk
+                                # Flush complete lines
+                                while b'\n' in stdout_buffer:
+                                    line, stdout_buffer = stdout_buffer.split(b'\n', 1)
+                                    line += b'\n'
+                                    yield from flush_buffer(line, 1)
+                        except BlockingIOError:
+                            pass
+
+                    # Read from stderr if available
+                    if self.process.stderr in readable:
+                        try:
+                            chunk = self.process.stderr.read(chunk_size)
+                            if chunk:
+                                stderr_buffer += chunk
+                                # Flush complete lines
+                                while b'\n' in stderr_buffer:
+                                    line, stderr_buffer = stderr_buffer.split(b'\n', 1)
+                                    line += b'\n'
+                                    yield from flush_buffer(line, 2)
+                        except BlockingIOError:
+                            pass
+
+                    # If process has ended, read any remaining data and exit
+                    if poll_result is not None:
+                        # Read any remaining buffered data
+                        while True:
+                            try:
+                                chunk = self.process.stdout.read(chunk_size)
+                                if not chunk:
+                                    break
+                                stdout_buffer += chunk
+                            except (BlockingIOError, ValueError):
+                                break
+
+                        while True:
+                            try:
+                                chunk = self.process.stderr.read(chunk_size)
+                                if not chunk:
+                                    break
+                                stderr_buffer += chunk
+                            except (BlockingIOError, ValueError):
+                                break
+
+                        # Flush any remaining complete lines
+                        while b'\n' in stdout_buffer:
+                            line, stdout_buffer = stdout_buffer.split(b'\n', 1)
+                            line += b'\n'
+                            yield from flush_buffer(line, 1)
+                        while b'\n' in stderr_buffer:
+                            line, stderr_buffer = stderr_buffer.split(b'\n', 1)
+                            line += b'\n'
+                            yield from flush_buffer(line, 2)
+
+                        # Flush any remaining partial lines
+                        yield from flush_buffer(stdout_buffer, 1)
+                        yield from flush_buffer(stderr_buffer, 2)
+
+                        # Send exit code
+                        self._returncode = self.process.returncode
+                        exit_code_str = str(self._returncode)
+                        exit_code_bytes = exit_code_str.encode('utf-8')
+                        header = f"- {len(exit_code_bytes)} ".encode()
+                        for byte in header:
+                            yield bytes([byte])
+                        for byte in exit_code_bytes:
+                            yield bytes([byte])
+                        break
+
+        return StreamingMockResponse(process)
 
     def run_python(self, gateway, files):
         """
@@ -115,6 +248,7 @@ class DirectIPSession:
 
         # Extract the script content and arguments from files
         script_content = None
+        module_content = None
         args = []
         env_vars = []
 
@@ -124,159 +258,163 @@ class DirectIPSession:
                     script_content = content.read().decode('utf-8')
                 else:
                     script_content = content.decode('utf-8')
+            elif name == 'module':
+                # Module is a zipped directory
+                module_content = content
             elif name == 'args':
                 args.append(content)
             elif name == 'env':
                 env_vars.append(content)
 
-        if not script_content:
-            raise ValueError("No script content found")
+        if not script_content and not module_content:
+            raise ValueError("No script or module content found")
 
-        # Create a temporary file to transfer the script
-        with tempfile.NamedTemporaryFile(mode='w', suffix='.py', delete=False) as f:
-            f.write(script_content)
-            temp_script = f.name
+        # Handle module (zipped directory) case
+        if module_content:
+            # Create temporary local zip file
+            with tempfile.NamedTemporaryFile(mode='wb', suffix='.zip', delete=False) as f:
+                f.write(module_content)
+                temp_zip = f.name
 
-        try:
-            # Build the remote command that will run in the container
-            # We need to properly quote arguments for shell execution through SSH
-            import shlex
+            try:
+                # Generate unique remote paths
+                import uuid
+                remote_id = str(uuid.uuid4())[:8]
+                remote_zip = f'/tmp/lager_module_{remote_id}.zip'
+                remote_dir = f'/tmp/lager_module_{remote_id}'
 
-            # Build the docker exec command with environment variables
-            docker_cmd_parts = ['docker', 'exec', '-i']
-            for env_var in env_vars:
-                docker_cmd_parts.extend(['-e', shlex.quote(env_var)])
+                # Transfer zip to gateway
+                subprocess.run(
+                    ['scp', '-q', '-o', 'LogLevel=ERROR', temp_zip, f'{self.ssh_host}:{remote_zip}'],
+                    check=True
+                )
 
-            # Add container name and python command
-            docker_cmd_parts.extend(['python', 'python3', '-'])
+                # Extract on gateway using Python (since unzip might not be available)
+                extract_cmd = f'python3 -c "import zipfile; z = zipfile.ZipFile(\'{remote_zip}\'); z.extractall(\'{remote_dir}\')"'
+                result = subprocess.run(
+                    ['ssh', '-o', 'LogLevel=ERROR', self.ssh_host, extract_cmd],
+                    capture_output=True,
+                    text=True
+                )
+                if result.returncode != 0:
+                    raise RuntimeError(f"Failed to extract module on gateway: {result.stderr}")
 
-            # Add script arguments with proper quoting
-            for arg in args:
-                docker_cmd_parts.append(shlex.quote(arg))
+                # Copy the extracted module into the container
+                container_dir = f'/tmp/lager_module_{remote_id}'
+                subprocess.run(
+                    ['ssh', '-o', 'LogLevel=ERROR', self.ssh_host,
+                     f'docker cp {remote_dir}/. python:{container_dir}'],
+                    check=True
+                )
 
-            # Join into a single command string for SSH to execute
-            docker_cmd = ' '.join(docker_cmd_parts)
+                # Build the remote command
+                import shlex
+                docker_cmd_parts = ['docker', 'exec', '-i']
+                for env_var in env_vars:
+                    docker_cmd_parts.extend(['-e', shlex.quote(env_var)])
 
-            # Build the SSH command
-            cmd = ['ssh', '-o', 'LogLevel=ERROR', self.ssh_host, docker_cmd]
+                # Set working directory and add module directory to PYTHONPATH
+                # Prepend container_dir to PYTHONPATH so imports from the module work
+                # Include /app/gateway_python for lager module access
+                docker_cmd_parts.extend(['-w', container_dir])
+                docker_cmd_parts.extend(['-e', 'PYTHONPATH=.:/app/gateway_python:/app'])
+                # Set LAGER_HOST_MODULE_FOLDER for error reporting
+                docker_cmd_parts.extend(['-e', f'LAGER_HOST_MODULE_FOLDER={container_dir}'])
 
-            # Execute script in container by piping it via stdin
-            # Use Popen instead of run() to enable real-time streaming output
-            process = subprocess.Popen(
-                cmd,
-                stdin=subprocess.PIPE,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
-                text=False  # Use binary mode for streaming
-            )
+                # Run main.py (working directory is already set to container_dir)
+                docker_cmd_parts.extend(['python', 'python3', 'main.py'])
 
-            # Write the script to stdin and close it
-            process.stdin.write(script_content.encode('utf-8'))
-            process.stdin.close()
+                # Add script arguments
+                for arg in args:
+                    docker_cmd_parts.append(shlex.quote(arg))
 
-            # Create a streaming response object
-            class StreamingMockResponse:
-                def __init__(self, process):
-                    self.process = process
-                    self.headers = {'Lager-Output-Version': '1'}
-                    self._returncode = None
+                docker_cmd = ' '.join(docker_cmd_parts)
+                cmd = ['ssh', '-o', 'LogLevel=ERROR', self.ssh_host, docker_cmd]
 
-                def iter_content(self, chunk_size=1024):
-                    """Stream output in real-time using v1 protocol format"""
-                    import select
-                    import os
-                    import time
+                # Execute
+                process = subprocess.Popen(
+                    cmd,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.PIPE,
+                    text=False
+                )
 
-                    # Set stdout and stderr to non-blocking mode
-                    import fcntl
-                    flags = fcntl.fcntl(self.process.stdout, fcntl.F_GETFL)
-                    fcntl.fcntl(self.process.stdout, fcntl.F_SETFL, flags | os.O_NONBLOCK)
-                    flags = fcntl.fcntl(self.process.stderr, fcntl.F_GETFL)
-                    fcntl.fcntl(self.process.stderr, fcntl.F_SETFL, flags | os.O_NONBLOCK)
+                # Get the streaming response
+                response = self._create_streaming_response(process)
 
-                    # Stream output until process completes
-                    while True:
-                        # Check if process has terminated
-                        poll_result = self.process.poll()
+                # Schedule cleanup after execution
+                import atexit
+                def cleanup():
+                    # Clean up files from container
+                    subprocess.run(
+                        ['ssh', '-o', 'LogLevel=ERROR', self.ssh_host,
+                         f'docker exec python rm -rf {container_dir}'],
+                        capture_output=True
+                    )
+                    # Clean up files from gateway host
+                    subprocess.run(
+                        ['ssh', '-o', 'LogLevel=ERROR', self.ssh_host,
+                         f'rm -rf {remote_dir} {remote_zip}'],
+                        capture_output=True
+                    )
+                atexit.register(cleanup)
 
-                        # Use select to wait for data with timeout
-                        readable, _, _ = select.select(
-                            [self.process.stdout, self.process.stderr],
-                            [], [],
-                            0.1  # 100ms timeout
-                        )
+                return response
 
-                        # Read from stdout if available
-                        if self.process.stdout in readable:
-                            try:
-                                chunk = self.process.stdout.read(chunk_size)
-                                if chunk:
-                                    header = f"1 {len(chunk)} ".encode()
-                                    for byte in header:
-                                        yield bytes([byte])
-                                    for byte in chunk:
-                                        yield bytes([byte])
-                            except BlockingIOError:
-                                pass
+            finally:
+                # Clean up local temp file
+                os.unlink(temp_zip)
 
-                        # Read from stderr if available
-                        if self.process.stderr in readable:
-                            try:
-                                chunk = self.process.stderr.read(chunk_size)
-                                if chunk:
-                                    header = f"2 {len(chunk)} ".encode()
-                                    for byte in header:
-                                        yield bytes([byte])
-                                    for byte in chunk:
-                                        yield bytes([byte])
-                            except BlockingIOError:
-                                pass
+        # Handle script case (existing logic)
+        else:
+            # Create a temporary file to transfer the script
+            with tempfile.NamedTemporaryFile(mode='w', suffix='.py', delete=False) as f:
+                f.write(script_content)
+                temp_script = f.name
 
-                        # If process has ended, read any remaining data and exit
-                        if poll_result is not None:
-                            # Read any remaining buffered data
-                            while True:
-                                try:
-                                    chunk = self.process.stdout.read(chunk_size)
-                                    if not chunk:
-                                        break
-                                    header = f"1 {len(chunk)} ".encode()
-                                    for byte in header:
-                                        yield bytes([byte])
-                                    for byte in chunk:
-                                        yield bytes([byte])
-                                except (BlockingIOError, ValueError):
-                                    break
+            try:
+                # Build the remote command that will run in the container
+                # We need to properly quote arguments for shell execution through SSH
+                import shlex
 
-                            while True:
-                                try:
-                                    chunk = self.process.stderr.read(chunk_size)
-                                    if not chunk:
-                                        break
-                                    header = f"2 {len(chunk)} ".encode()
-                                    for byte in header:
-                                        yield bytes([byte])
-                                    for byte in chunk:
-                                        yield bytes([byte])
-                                except (BlockingIOError, ValueError):
-                                    break
+                # Build the docker exec command with environment variables
+                docker_cmd_parts = ['docker', 'exec', '-i']
+                for env_var in env_vars:
+                    docker_cmd_parts.extend(['-e', shlex.quote(env_var)])
 
-                            # Send exit code
-                            self._returncode = self.process.returncode
-                            exit_code_str = str(self._returncode)
-                            exit_code_bytes = exit_code_str.encode('utf-8')
-                            header = f"- {len(exit_code_bytes)} ".encode()
-                            for byte in header:
-                                yield bytes([byte])
-                            for byte in exit_code_bytes:
-                                yield bytes([byte])
-                            break
+                # Add container name and python command
+                docker_cmd_parts.extend(['python', 'python3', '-'])
 
-            return StreamingMockResponse(process)
+                # Add script arguments with proper quoting
+                for arg in args:
+                    docker_cmd_parts.append(shlex.quote(arg))
 
-        finally:
-            # Clean up temporary file
-            os.unlink(temp_script)
+                # Join into a single command string for SSH to execute
+                docker_cmd = ' '.join(docker_cmd_parts)
+
+                # Build the SSH command
+                cmd = ['ssh', '-o', 'LogLevel=ERROR', self.ssh_host, docker_cmd]
+
+                # Execute script in container by piping it via stdin
+                # Use Popen instead of run() to enable real-time streaming output
+                process = subprocess.Popen(
+                    cmd,
+                    stdin=subprocess.PIPE,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.PIPE,
+                    text=False  # Use binary mode for streaming
+                )
+
+                # Write the script to stdin and close it
+                process.stdin.write(script_content.encode('utf-8'))
+                process.stdin.close()
+
+                # Create and return streaming response
+                return self._create_streaming_response(process)
+
+            finally:
+                # Clean up temporary file
+                os.unlink(temp_script)
 
     def gateway_hello(self, gateway):
         """
@@ -308,13 +446,138 @@ class DirectIPSession:
         return MockResponse("OK")
 
     def download_file(self, gateway, filename):
-        """Mock download_file - could be implemented with scp if needed"""
-        class MockResponse:
-            def __init__(self, text, status_code=200):
-                self.text = text
-                self.status_code = status_code
-                self.headers = {'Lager-Output-Version': '1'}
-        return MockResponse("File download not implemented for direct execution")
+        """Download a file from gateway using scp"""
+        import subprocess
+        import tempfile
+        import gzip
+        import shutil
+
+        class SCPResponse:
+            """Response-like object for SCP downloads that supports context manager protocol"""
+            def __init__(self, filepath):
+                self.filepath = filepath
+                self.gzipped_path = filepath + '.gz'
+                self._file = None
+                self.status_code = 200
+
+            def __enter__(self):
+                # Gzip the downloaded file (to match backend behavior)
+                try:
+                    with open(self.filepath, 'rb') as f_in:
+                        with gzip.open(self.gzipped_path, 'wb') as f_out:
+                            shutil.copyfileobj(f_in, f_out)
+
+                    # Open the gzipped file and expose it as .raw
+                    self._file = open(self.gzipped_path, 'rb')
+                    self.raw = self._file
+                    return self
+                except FileNotFoundError:
+                    # File wasn't downloaded successfully
+                    raise requests.HTTPError("File not found on gateway")
+
+            def __exit__(self, exc_type, exc_val, exc_tb):
+                if self._file:
+                    self._file.close()
+                # Clean up temp files
+                try:
+                    if os.path.exists(self.filepath):
+                        os.unlink(self.filepath)
+                    if os.path.exists(self.gzipped_path):
+                        os.unlink(self.gzipped_path)
+                except Exception:
+                    pass
+                return False
+
+            def raise_for_status(self):
+                """Compatibility method for requests-like behavior"""
+                if self.status_code >= 400:
+                    raise requests.HTTPError(f"HTTP {self.status_code}")
+
+        # Create a temporary file for the download
+        temp_file = tempfile.NamedTemporaryFile(delete=False, suffix='_download')
+        temp_file.close()
+
+        # Download file using scp
+        scp_cmd = ['scp', '-q', f'{self.ssh_host}:{filename}', temp_file.name]
+
+        try:
+            result = subprocess.run(scp_cmd, capture_output=True, check=True, timeout=60)
+            return SCPResponse(temp_file.name)
+        except subprocess.CalledProcessError as e:
+            # Clean up temp file on error
+            try:
+                os.unlink(temp_file.name)
+            except Exception:
+                pass
+
+            # Check if it's a file not found error (scp exit code 1)
+            error_msg = e.stderr.decode() if e.stderr else str(e)
+            if 'No such file' in error_msg or e.returncode == 1:
+                # Create a mock response that will raise HTTPError with 404
+                class NotFoundResponse:
+                    def __init__(self):
+                        self.status_code = 404
+                    def __enter__(self):
+                        return self
+                    def __exit__(self, *args):
+                        return False
+                    def raise_for_status(self):
+                        err = requests.HTTPError("File not found")
+                        err.response = self
+                        raise err
+                resp = NotFoundResponse()
+                resp.raise_for_status()
+            else:
+                raise requests.HTTPError(f"Failed to download file: {error_msg}")
+        except subprocess.TimeoutExpired:
+            # Clean up temp file on timeout
+            try:
+                os.unlink(temp_file.name)
+            except Exception:
+                pass
+            raise requests.HTTPError("Download timeout")
+
+    def run_pip(self, gateway, args):
+        """
+        Run pip commands in the python container via HTTP
+
+        Args:
+            gateway: Gateway identifier (IP address)
+            args: List of pip arguments (e.g., ['install', 'pandas'])
+
+        Returns:
+            HTTP response with streaming output
+        """
+        import requests
+
+        # Make HTTP request to the gateway's run-pip endpoint
+        url = f'http://{self.ip_address}:5001/run/pip'
+
+        try:
+            response = requests.post(
+                url,
+                json={'args': args},
+                stream=True,
+                timeout=600  # 10 minute timeout for pip operations
+            )
+
+            # Check for HTTP errors
+            if response.status_code != 200:
+                error_msg = f"HTTP {response.status_code}"
+                try:
+                    error_data = response.json()
+                    if 'error' in error_data:
+                        error_msg = error_data['error']
+                except:
+                    pass
+                raise requests.HTTPError(error_msg)
+
+            return response
+
+        except requests.exceptions.ConnectionError as e:
+            raise requests.HTTPError(f"Failed to connect to gateway at {self.ip_address}: {e}")
+        except requests.exceptions.Timeout:
+            raise requests.HTTPError("Pip operation timed out")
 
 
 class LagerSession(BaseUrlSession):
@@ -336,10 +599,10 @@ class LagerSession(BaseUrlSession):
             parts = r.request.path_url.split('/')
             if len(parts) > 2 and 'download-file?filename=' in parts[-1]:
                 r.raise_for_status()
-            name = ctx.params.get('gateway') or ctx.params.get('dut') or ctx.obj.default_gateway
-            click.secho('You don\'t have a gateway with id `{}`'.format(name), fg='red', err=True)
+            name = ctx.params.get('box') or ctx.params.get('dut') or ctx.obj.default_gateway
+            click.secho('You don\'t have a Lagerbox with id `{}`'.format(name), fg='red', err=True)
             click.secho(
-                'Please double check your login credentials and gateway id',
+                'Please double check your login credentials and Lagerbox id',
                 fg='red',
                 err=True,
             )
@@ -658,13 +921,6 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/rename'.format(quote(gateway))
         return self.post(url, json={'name': new_name})
 
-    def start_local_gdb_tunnel(self, gateway, fork):
-        """
-            Start the local gdb tunnel on gateway
-        """
-        url = 'gateway/{}/local-gdb'.format(quote(gateway))
-        return self.post(url, json={'fork': fork})
-
     def gpio_set(self, gateway, gpio, type_, pull):
         """
             Set a GPIO pin to input or output
@@ -885,6 +1141,95 @@ class LagerSession(BaseUrlSession):
         return self.get(url)
 
 
+class DirectHTTPSession:
+    """
+    Direct HTTP session to gateway over any network (VPN, local, etc.).
+
+    Network-agnostic: Works with Tailscale, WireGuard, corporate VPN, local network, or any IP.
+    Authorization: Network-level access (can you reach the IP via HTTP?)
+
+    This bypasses the backend proxy for faster execution.
+    """
+
+    def __init__(self, gateway_ip):
+        """
+        Initialize direct HTTP session to gateway.
+
+        Args:
+            gateway_ip: IP address of gateway (Tailscale, VPN, local, or public IP)
+        """
+        self.gateway_ip = gateway_ip
+        self.base_url = f'http://{gateway_ip}:5000'
+        self.session = requests.Session()
+
+        # Add version header
+        self.session.headers.update({
+            'Lager-Version': __version__,
+            'Lager-Invocation-Id': str(uuid4()),
+        })
+
+    def run_python(self, gateway, files):
+        """
+        Run python on gateway via direct HTTP.
+
+        Args:
+            gateway: Gateway IP (ignored, uses self.gateway_ip)
+            files: List of (name, content) tuples for multipart upload
+
+        Returns:
+            requests.Response object with streaming content
+        """
+        url = f'{self.base_url}/python'
+
+        try:
+            response = self.session.post(
+                url,
+                files=files,
+                stream=True,
+                timeout=(7, 320)  # Connect timeout: 7s, Read timeout: 320s
+            )
+            return response
+        except requests.exceptions.ConnectionError as e:
+            click.secho(f'Could not connect to gateway at {self.gateway_ip}', fg='red', err=True)
+            click.secho('Ensure the gateway is online and reachable via your network', fg='yellow', err=True)
+            click.secho('(Tailscale, VPN, or local network connection required)', fg='yellow', err=True)
+            raise
+        except requests.exceptions.Timeout:
+            click.secho(f'Connection to gateway at {self.gateway_ip} timed out', fg='red', err=True)
+            raise
+
+    def kill_python(self, gateway, lager_process_id, sig=signal.SIGTERM):
+        """
+        Kill python process on gateway.
+
+        Args:
+            gateway: Gateway IP (ignored)
+            lager_process_id: Process ID to kill
+            sig: Signal to send (default SIGTERM)
+        """
+        url = f'{self.base_url}/python/kill'
+        response = self.session.post(url, json={
+            'lager_process_id': lager_process_id,
+            'signal': int(sig)
+        })
+        response.raise_for_status()
+        return response
+
+    def gateway_hello(self, gateway):
+        """Say hello to gateway to test connectivity"""
+        url = f'{self.base_url}/hello'
+        return self.session.get(url)
+
+    def list_instruments(self, gateway):
+        """List instruments configured on gateway"""
+        url = f'{self.base_url}/instruments'
+        return self.session.get(url)
+
+    def nets(self, gateway):
+        """List nets configured on gateway"""
+        url = f'{self.base_url}/nets'
+        return self.session.get(url)
+
 
 class LagerContext:  # pylint: disable=too-few-public-methods
     """
@@ -901,16 +1246,33 @@ class LagerContext:  # pylint: disable=too-few-public-methods
         self.debug = debug
         self.interpreter = interpreter
 
-    def get_session_for_gateway(self, gateway):
+    def get_session_for_gateway(self, gateway, dut_name=None):
         """
-        Get appropriate session for gateway:
-        - IP addresses use DirectIPSession (SSH + docker exec)
-        - Gateway IDs use LagerSession (cloud backend API)
+        Get appropriate session for gateway.
+
+        Returns DirectHTTPSession for direct network connections (default).
+        Set LAGER_USE_BACKEND=1 to use legacy backend proxy mode.
+
+        Args:
+            gateway: IP address of gateway
+            dut_name: Optional DUT name (unused in direct HTTP mode)
+
+        Returns:
+            DirectHTTPSession (default) or LagerSession (if LAGER_USE_BACKEND=1)
         """
-        if is_ip_address(gateway):
-            return DirectIPSession(gateway)
-        # Gateway ID - use cloud backend (may require auth via environment variables)
-        return self.session
+        # Check if user wants to force backend mode (for debugging/fallback)
+        use_backend = os.getenv('LAGER_USE_BACKEND', '0') == '1'
+
+        if use_backend:
+            if self.debug:
+                click.echo(f"[DEBUG] Using backend session (LAGER_USE_BACKEND=1)", err=True)
+            return self.session  # LagerSession (backend proxy)
+
+        # Use direct HTTP by default (network-agnostic: works with any VPN/network)
+        if self.debug:
+            click.echo(f"[DEBUG] Using direct HTTP to {gateway}", err=True)
+
+        return DirectHTTPSession(gateway)
 
     @property
     def default_gateway(self):
@@ -985,8 +1347,8 @@ def get_default_gateway(ctx):
                 click.echo(f'  - {dut_name}')
             click.echo()
             click.echo('You can either:')
-            click.echo('  1. Specify a DUT with: --dut <name>')
-            click.echo('  2. Set a default DUT with: lager defaults add --dut <name>')
+            click.echo('  1. Specify a box with: --box <name>')
+            click.echo('  2. Set a default box with: lager defaults add --box <name>')
         else:
             click.echo('No local DUTs found in .lager file.')
             click.echo()
@@ -994,8 +1356,8 @@ def get_default_gateway(ctx):
             click.echo('  lager duts add --name <name> --ip <ip-address>')
             click.echo()
             click.echo('Then you can either:')
-            click.echo('  1. Specify a DUT with: --dut <name>')
-            click.echo('  2. Set a default DUT with: lager defaults add --dut <name>')
+            click.echo('  1. Specify a box with: --box <name>')
+            click.echo('  2. Set a default box with: lager defaults add --box <name>')
 
         ctx.exit(1)
 
@@ -1106,3 +1468,25 @@ def get_impl_path(filename):
     return os.path.join(base, 'impl', filename)
 
 
+def get_default_net(ctx, net_type):
+    """
+    Get the default net name for a specific net type from config.
+
+    Args:
+        ctx: Click context
+        net_type: Type of net (e.g., 'power_supply', 'battery', 'scope', etc.)
+
+    Returns:
+        Default net name if configured, None otherwise
+    """
+    from .config import read_config_file
+
+    config_key = f'net_{net_type}'
+    config = read_config_file()
+
+    if config.has_option('LAGER', config_key):
+        return config.get('LAGER', config_key)
+
+    return None
+
+
