@@ -20,19 +20,20 @@ def duts(ctx):
         # Default behavior: list DUTs
         table = Texttable()
         table.set_deco(Texttable.HEADER)
-        table.set_cols_dtype(['t', 't'])
-        table.set_cols_align(["l", "l"])
-        table.add_row(['name', 'ip'])
+        table.set_cols_dtype(['t', 't', 't'])
+        table.set_cols_align(["l", "l", "l"])
+        table.add_row(['name', 'ip', 'user'])
 
         # Show only saved local DUTs
         saved_duts = list_duts()
         for name, dut_info in sorted(saved_duts.items()):
             if isinstance(dut_info, dict):
                 ip = dut_info.get('ip', 'unknown')
-                table.add_row([name, ip])
+                user = dut_info.get('user', '-')
+                table.add_row([name, ip, user])
             else:
                 # Handle simple string format (IP only)
-                table.add_row([name, dut_info])
+                table.add_row([name, dut_info, '-'])
 
         if not saved_duts:
             click.echo("No local DUTs found. Add one with: lager duts add --name <NAME> --ip <IP>")
@@ -43,8 +44,9 @@ def duts(ctx):
 @duts.command()
 @click.option('--name', required=True, help='Name to assign to the DUT')
 @click.option('--ip', required=True, help='IP address of the DUT')
+@click.option('--user', required=False, help='Username for SSH connection (defaults to lagerdata)')
 @click.option('--yes', is_flag=True, help='Confirm the action without prompting.')
-def add(name, ip, yes):
+def add(name, ip, user, yes):
     """
         Add a DUT configuration
     """
@@ -140,14 +142,19 @@ def add(name, ip, yes):
             click.echo(f"\nYou are about to add the following DUT:")
             click.echo(f"  Name: {name}")
             click.echo(f"  IP:   {ip}")
+            if user:
+                click.echo(f"  User: {user}")
             click.echo()
 
             if not click.confirm("Add this DUT?", default=False):
                 click.echo("Cancelled. DUT not added.")
                 return
 
-    add_dut(name, ip)
-    click.echo(click.style(f"Added DUT '{name}' with IP '{ip}'", fg='green'))
+    add_dut(name, ip, user)
+    success_msg = f"Added DUT '{name}' with IP '{ip}'"
+    if user:
+        success_msg += f" (user: {user})"
+    click.echo(click.style(success_msg, fg='green'))
 
 
 @duts.command('delete')
@@ -190,15 +197,16 @@ def delete(name, yes):
 @duts.command('edit')
 @click.option('--name', required=True, help='Name of the DUT to edit')
 @click.option('--ip', required=False, help='New IP address for the DUT')
+@click.option('--user', required=False, help='New username for SSH connection')
 @click.option('--new-name', required=False, help='New name for the DUT')
 @click.option('--yes', is_flag=True, help='Confirm the action without prompting.')
-def edit(name, ip, new_name, yes):
+def edit(name, ip, user, new_name, yes):
     """
         Edit a DUT configuration
     """
     # Check if at least one change is specified
-    if ip is None and new_name is None:
-        click.echo(click.style("Error: You must specify at least one change (--ip or --new-name)", fg='red'), err=True)
+    if ip is None and new_name is None and user is None:
+        click.echo(click.style("Error: You must specify at least one change (--ip, --user, or --new-name)", fg='red'), err=True)
         raise click.Abort()
 
     # Check if DUT exists
@@ -209,10 +217,16 @@ def edit(name, ip, new_name, yes):
 
     # Get current DUT info
     dut_info = existing_duts[name]
-    current_ip = dut_info.get('ip') if isinstance(dut_info, dict) else dut_info
+    if isinstance(dut_info, dict):
+        current_ip = dut_info.get('ip')
+        current_user = dut_info.get('user')
+    else:
+        current_ip = dut_info
+        current_user = None
 
     # Determine new values (keep old if not specified)
     updated_ip = ip if ip else current_ip
+    updated_user = user if user is not None else current_user
     updated_name = new_name if new_name else name
 
     # Validate new IP if specified
@@ -246,14 +260,24 @@ def edit(name, ip, new_name, yes):
     # Display what will change and ask for confirmation unless --yes flag is provided
     if not yes:
         click.echo(f"\nYou are about to edit the following DUT:")
-        click.echo(f"  Current: {name} → {current_ip}")
+        current_display = f"  Current: {name} → {current_ip}"
+        if current_user:
+            current_display += f" (user: {current_user})"
+        click.echo(current_display)
 
-        if ip and new_name:
-            click.echo(f"  New:     {updated_name} → {updated_ip}")
-        elif ip:
-            click.echo(f"  New IP:  {updated_ip}")
-        elif new_name:
-            click.echo(f"  New Name: {updated_name}")
+        changes = []
+        if new_name:
+            changes.append(f"name: {name} → {updated_name}")
+        if ip:
+            changes.append(f"IP: {current_ip} → {updated_ip}")
+        if user is not None:
+            if current_user:
+                changes.append(f"user: {current_user} → {updated_user}")
+            else:
+                changes.append(f"user: (none) → {updated_user}")
+
+        for change in changes:
+            click.echo(f"  Change:  {change}")
         click.echo()
 
         if not click.confirm("Apply these changes?", default=False):
@@ -266,14 +290,21 @@ def edit(name, ip, new_name, yes):
         delete_dut(name)
 
     # Add/update with new values
-    add_dut(updated_name, updated_ip)
+    add_dut(updated_name, updated_ip, updated_user)
 
-    if ip and new_name:
-        click.echo(click.style(f"Updated DUT: renamed '{name}' to '{updated_name}' and changed IP to '{updated_ip}'", fg='green'))
-    elif ip:
-        click.echo(click.style(f"Updated DUT '{name}' IP to '{updated_ip}'", fg='green'))
-    elif new_name:
-        click.echo(click.style(f"Renamed DUT '{name}' to '{updated_name}'", fg='green'))
+    # Build success message
+    changes_made = []
+    if new_name and new_name != name:
+        changes_made.append(f"renamed '{name}' to '{updated_name}'")
+    if ip:
+        changes_made.append(f"changed IP to '{updated_ip}'")
+    if user is not None:
+        changes_made.append(f"changed user to '{updated_user}'")
+
+    success_msg = f"Updated DUT"
+    if changes_made:
+        success_msg += ": " + ", ".join(changes_made)
+    click.echo(click.style(success_msg, fg='green'))
 
 
 @duts.command('delete-all')
