@@ -478,7 +478,7 @@ def flash(args):
     jlink_status = get_jlink_status()
     if not jlink_status['running']:
         print(f"{RED}ERROR: No debugger connection found{RESET}")
-        print("Connect first: lager debug <net> connect --dut <dut>")
+        print("Connect first: lager debug <net> connect --box <box>")
         sys.exit(1)
 
     # Files are already transferred to the gateway, read them from disk
@@ -629,7 +629,7 @@ def flash(args):
         connect(connect_args)
     except Exception as e:
         print(f"{RED}WARNING: Failed to reconnect debugger: {str(e)}{RESET}")
-        print("You may need to manually connect: lager debug <net> connect --dut <dut>")
+        print("You may need to manually connect: lager debug <net> connect --box <box>")
         sys.exit(1)
 
     # CRITICAL: After reconnecting J-Link GDB Server, we MUST reset the device
@@ -655,7 +655,7 @@ def flash(args):
 
     except Exception as e:
         print(f"{RED}WARNING: Failed to reset device: {str(e)}{RESET}")
-        print("Try manually resetting: lager debug <net> reset --dut <dut>")
+        print("Try manually resetting: lager debug <net> reset --box <box>")
 
     # If --logs flag is set, stream RTT logs
     stream_logs = args.get('stream_logs', False)
@@ -727,7 +727,7 @@ def rtt_logs(args):
     jlink_status = get_jlink_status()
     if not jlink_status['running']:
         print(f"{RED}ERROR: No debugger connection found{RESET}", file=sys.stderr)
-        print("Connect first: lager debug <net> connect --dut <dut>", file=sys.stderr)
+        print("Connect first: lager debug <net> connect --box <box>", file=sys.stderr)
         sys.exit(1)
 
     # Determine RTT port based on channel (9090 for channel 0, 9091 for channel 1)
@@ -753,7 +753,7 @@ def rtt_logs(args):
             print(f"{RED}ERROR: Cannot connect to RTT telnet port (localhost:{rtt_port}){RESET}", file=sys.stderr)
             print(f"Connection error: {conn_err}", file=sys.stderr)
             print("\nPossible causes:", file=sys.stderr)
-            print("  1. Debugger not connected (run: lager debug <net> connect --dut <dut>)", file=sys.stderr)
+            print("  1. Debugger not connected (run: lager debug <net> connect --box <box>)", file=sys.stderr)
             print("  2. Firmware does not have RTT support compiled in", file=sys.stderr)
             print("  3. RTT control block not found in device memory", file=sys.stderr)
             print("  4. J-Link GDB server RTT port not listening", file=sys.stderr)
