@@ -9,7 +9,7 @@ from contextlib import redirect_stdout
 
 import click
 from texttable import Texttable
-from ..context import get_default_gateway, get_impl_path
+from ..context import get_default_gateway, get_impl_path, get_default_net
 from ..python.commands import run_python_internal
 
 LOGIC_ROLE = "logic"
@@ -28,12 +28,12 @@ def _require_netname(ctx) -> str:
     return netname
 
 
-def _resolve_gateway(ctx, gateway, dut):
+def _resolve_gateway(ctx, box, dut):
     from ..dut_storage import get_dut_ip
 
-    # Check if gateway is a local DUT name first
-    if gateway:
-        local_ip = get_dut_ip(gateway)
+    # Check if box is a local DUT name first
+    if box:
+        local_ip = get_dut_ip(box)
         if local_ip:
             return local_ip
 
@@ -43,7 +43,7 @@ def _resolve_gateway(ctx, gateway, dut):
         if local_ip:
             return local_ip
 
-    return gateway or dut or get_default_gateway(ctx)
+    return box or dut or get_default_gateway(ctx)
 
 
 def _run_net_py(ctx: click.Context, dut: str, *args: str) -> list[dict]:
@@ -76,21 +76,21 @@ def _run_net_py(ctx: click.Context, dut: str, *args: str) -> list[dict]:
         return []
 
 
-def _list_logic_nets(ctx, gateway):
-    recs = _run_net_py(ctx, gateway, "list")
+def _list_logic_nets(ctx, box):
+    recs = _run_net_py(ctx, box, "list")
     return [r for r in recs if r.get("role") == LOGIC_ROLE]
 
 
-def validate_net(ctx, gateway, netname, net_role):
+def validate_net(ctx, box, netname, net_role):
     """Validate that a net exists and has the specified role using locally saved nets"""
-    nets = _run_net_py(ctx, gateway, "list")
+    nets = _run_net_py(ctx, box, "list")
     for net in nets:
         if net.get("name") == netname and net.get("role") == net_role:
             return True
     return False
 
 
-def display_nets(ctx, gateway, netname: str | None):
+def display_nets(ctx, box, netname: str | None):
     table = Texttable()
     table.set_deco(Texttable.HEADER)
     table.set_cols_dtype(["t", "t", "t"])
@@ -109,17 +109,21 @@ def display_nets(ctx, gateway, netname: str | None):
 @click.group(invoke_without_command=True)
 @click.argument("NETNAME", required=False)
 @click.pass_context
-@click.option("--gateway", required=False, help="ID of gateway to which DUT is connected", hidden=True)
-@click.option("--dut", required=False, help="ID of DUT")
-def logic(ctx, gateway, dut, netname):
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="ID of DUT")
+def logic(ctx, box, dut, netname):
     """
         Control logic analyzer channels and triggers
     """
+    # Use provided netname, or fall back to default if not provided
+    if netname is None:
+        netname = get_default_net(ctx, 'logic')
+
     if netname is not None:
         ctx.obj.netname = netname
 
     if ctx.invoked_subcommand is None:
-        gw = _resolve_gateway(ctx, gateway, dut)
+        gw = _resolve_gateway(ctx, box, dut)
         display_nets(ctx, gw, None)    
 
 
@@ -151,17 +155,17 @@ def _run_backend(ctx, dut, action: str, **params):
 
 @logic.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="ID of gateway to which DUT is connected", hidden=True)
-@click.option("--dut", required=False, help="ID of DUT")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="ID of DUT")
 @click.option("--mcu", required=False)
-def disable(ctx, gateway, dut, mcu):
+def disable(ctx, box, dut, mcu):
     """
         Disable Net
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -169,17 +173,17 @@ def disable(ctx, gateway, dut, mcu):
 
 @logic.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="ID of gateway to which DUT is connected", hidden=True)
-@click.option("--dut", required=False, help="ID of DUT")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="ID of DUT")
 @click.option("--mcu", required=False)
-def enable(ctx, gateway, dut, mcu):
+def enable(ctx, box, dut, mcu):
     """
         Enable Net
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -187,17 +191,17 @@ def enable(ctx, gateway, dut, mcu):
 
 @logic.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="ID of gateway to which DUT is connected", hidden=True)
-@click.option("--dut", required=False, help="ID of DUT")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="ID of DUT")
 @click.option("--mcu", required=False)
-def start(ctx, gateway, dut, mcu):
+def start(ctx, box, dut, mcu):
     """
         Start waveform capture
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -205,17 +209,17 @@ def start(ctx, gateway, dut, mcu):
 
 @logic.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="ID of gateway to which DUT is connected", hidden=True)
-@click.option("--dut", required=False, help="ID of DUT")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="ID of DUT")
 @click.option("--mcu", required=False)
-def start_single(ctx, gateway, dut, mcu):
+def start_single(ctx, box, dut, mcu):
     """
         Start a single waveform capture
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -223,17 +227,17 @@ def start_single(ctx, gateway, dut, mcu):
 
 @logic.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="ID of gateway to which DUT is connected", hidden=True)
-@click.option("--dut", required=False, help="ID of DUT")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="ID of DUT")
 @click.option("--mcu", required=False)
-def stop(ctx, gateway, dut, mcu):
+def stop(ctx, box, dut, mcu):
     """
         Stop waveform capture
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -328,18 +332,18 @@ def _run_cursor_backend(ctx, dut, action: str, **params):
 @measure.command()
 @click.pass_context
 @click.option("--mcu", required=False)
-@click.option("--gateway", required=False, help="ID of gateway to which DUT is connected", hidden=True)
-@click.option("--dut", required=False, help="ID of DUT")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="ID of DUT")
 @click.option("--display", default=False, type=click.BOOL, help="Display measurement on screen")
 @click.option("--cursor", default=False, type=click.BOOL, help="Enable measurement cursor")
-def period(ctx, mcu, gateway, dut, display, cursor):
+def period(ctx, mcu, box, dut, display, cursor):
     """
     Measure period of captured net waveform
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -348,18 +352,18 @@ def period(ctx, mcu, gateway, dut, display, cursor):
 @measure.command()
 @click.pass_context
 @click.option('--mcu', required=False)
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--display', default=False, type=click.BOOL, help='Display measurement on screen')
 @click.option('--cursor', default=False, type=click.BOOL, help='Enable measurement cursor')
-def freq(ctx, mcu, gateway, dut, display, cursor):
+def freq(ctx, mcu, box, dut, display, cursor):
     """
     Measure frequency of captured net waveform
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -368,18 +372,18 @@ def freq(ctx, mcu, gateway, dut, display, cursor):
 @measure.command()
 @click.pass_context
 @click.option('--mcu', required=False)
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--display', default=False, type=click.BOOL, help='Display measurement on screen')
 @click.option('--cursor', default=False, type=click.BOOL, help='Enable measurement cursor')
-def dc_pos(ctx, mcu, gateway, dut, display, cursor):
+def dc_pos(ctx, mcu, box, dut, display, cursor):
     """
     Measure positive duty cycle
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -388,18 +392,18 @@ def dc_pos(ctx, mcu, gateway, dut, display, cursor):
 @measure.command()
 @click.pass_context
 @click.option('--mcu', required=False)
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--display', default=False, type=click.BOOL, help='Display measurement on screen')
 @click.option('--cursor', default=False, type=click.BOOL, help='Enable measurement cursor')
-def dc_neg(ctx, mcu, gateway, dut, display, cursor):
+def dc_neg(ctx, mcu, box, dut, display, cursor):
     """
     Measure negative duty cycle
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -408,18 +412,18 @@ def dc_neg(ctx, mcu, gateway, dut, display, cursor):
 @measure.command()
 @click.pass_context
 @click.option('--mcu', required=False)
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--display', default=False, type=click.BOOL, help='Display measurement on screen')
 @click.option('--cursor', default=False, type=click.BOOL, help='Enable measurement cursor')
-def pw_pos(ctx, mcu, gateway, dut, display, cursor):
+def pw_pos(ctx, mcu, box, dut, display, cursor):
     """
     Measure positive pulse width
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -428,18 +432,18 @@ def pw_pos(ctx, mcu, gateway, dut, display, cursor):
 @measure.command()
 @click.pass_context
 @click.option('--mcu', required=False)
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--display', default=False, type=click.BOOL, help='Display measurement on screen')
 @click.option('--cursor', default=False, type=click.BOOL, help='Enable measurement cursor')
-def pw_neg(ctx, mcu, gateway, dut, display, cursor):
+def pw_neg(ctx, mcu, box, dut, display, cursor):
     """
     Measure negative pulse width
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -460,21 +464,21 @@ COUPLING_CHOICES = click.Choice(('dc', 'ac', 'low_freq_rej', 'high_freq_rej'))
 @trigger.command()
 @click.pass_context
 @click.option('--mcu', required=False)
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mode', default='normal', type=MODE_CHOICES, help='Trigger mode', show_default=True)
 @click.option('--coupling', default='dc', type=COUPLING_CHOICES, help='Coupling mode', show_default=True)
 @click.option('--source', required=False, help='Trigger source', metavar='NET')
 @click.option('--slope', type=click.Choice(('rising', 'falling', 'both')), help='Trigger slope')
 @click.option('--level', type=click.FLOAT, help='Trigger level')
-def edge(ctx, mcu, gateway, dut, mode, coupling, source, slope, level):
+def edge(ctx, mcu, box, dut, mode, coupling, source, slope, level):
     """
     Set edge trigger
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -484,8 +488,8 @@ def edge(ctx, mcu, gateway, dut, mode, coupling, source, slope, level):
 @trigger.command()
 @click.pass_context
 @click.option('--mcu', required=False)
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mode', default='normal', type=MODE_CHOICES, help='Trigger mode', show_default=True)
 @click.option('--coupling', default='dc', type=COUPLING_CHOICES, help='Coupling mode', show_default=True)
 @click.option('--source', required=False, help='Trigger source', metavar='NET')
@@ -493,14 +497,14 @@ def edge(ctx, mcu, gateway, dut, mode, coupling, source, slope, level):
 @click.option('--trigger-on', type=click.Choice(('gt', 'lt', 'gtlt')), help='Trigger on')
 @click.option('--upper', type=click.FLOAT, help='upper width')
 @click.option('--lower', type=click.FLOAT, help='lower width')
-def pulse(ctx, mcu, gateway, dut, mode, coupling, source, level, trigger_on, upper, lower):
+def pulse(ctx, mcu, box, dut, mode, coupling, source, level, trigger_on, upper, lower):
     """
     Set pulse trigger
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -508,8 +512,8 @@ def pulse(ctx, mcu, gateway, dut, mode, coupling, source, level, trigger_on, upp
 
 @trigger.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
 @click.option('--mode', default='normal', type=MODE_CHOICES, help='Trigger mode, e.g. Normal, Automatic, or Single Shot', show_default=True)
 @click.option('--coupling', default='dc', type=COUPLING_CHOICES, help='Coupling mode', show_default=True)
@@ -523,7 +527,7 @@ def pulse(ctx, mcu, gateway, dut, mode, coupling, source, level, trigger_on, upp
 @click.option('--data', type=click.INT, help='Data value to trigger on in DATA mode')
 @click.option('--data-width', type=click.Choice(('1', '2', '3', '4', '5')), help='Data width in bytes')
 @click.option('--direction', type=click.Choice(('write', 'read', 'rw')), help='Direction to trigger on')
-def i2c(ctx, gateway, dut, mcu, mode, coupling, source_scl, level_scl, source_sda, level_sda, trigger_on, address, addr_width, data, data_width, direction):
+def i2c(ctx, box, dut, mcu, mode, coupling, source_scl, level_scl, source_sda, level_sda, trigger_on, address, addr_width, data, data_width, direction):
     """
     Set I2C trigger
     """
@@ -532,10 +536,10 @@ def i2c(ctx, gateway, dut, mcu, mode, coupling, source_scl, level_scl, source_sd
     if data_width is not None:
         data_width = int(data_width)
 
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -543,8 +547,8 @@ def i2c(ctx, gateway, dut, mcu, mode, coupling, source_scl, level_scl, source_sd
 
 @trigger.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
 @click.option('--mode', default='normal', type=MODE_CHOICES, help='Trigger mode, e.g. Normal, Automatic, or Single Shot', show_default=True)
 @click.option('--coupling', default='dc', type=COUPLING_CHOICES, help='Coupling mode', show_default=True)
@@ -556,17 +560,17 @@ def i2c(ctx, gateway, dut, mcu, mode, coupling, source_scl, level_scl, source_sd
 @click.option('--baud', type=click.INT, help='Data trigger baud')
 @click.option('--data-width', type=click.INT, help='Data trigger data width in bits')
 @click.option('--data', type=click.INT, help='Data trigger data')
-def uart(ctx, gateway, dut, mcu, mode, coupling, source, level, trigger_on, parity, stop_bits, baud, data_width, data):
+def uart(ctx, box, dut, mcu, mode, coupling, source, level, trigger_on, parity, stop_bits, baud, data_width, data):
     """
     Set UART trigger
     """
     if stop_bits is not None:
         stop_bits = float(stop_bits)
 
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -574,8 +578,8 @@ def uart(ctx, gateway, dut, mcu, mode, coupling, source, level, trigger_on, pari
 
 @trigger.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
 @click.option('--mode', default='normal', type=MODE_CHOICES, help='Trigger mode, e.g. Normal, Automatic, or Single Shot', show_default=True)
 @click.option('--coupling', default='dc', type=COUPLING_CHOICES, help='Coupling mode', show_default=True)
@@ -591,14 +595,14 @@ def uart(ctx, gateway, dut, mcu, mode, coupling, source, level, trigger_on, pari
 @click.option('--trigger-on', type=click.Choice(('timeout', 'cs')), help='Trigger on')
 @click.option('--cs-idle', type=click.Choice(('high', 'low')), help='CS Idle type')
 @click.option('--timeout', type=click.FLOAT, help='Timeout length')
-def spi(ctx, gateway, dut, mcu, mode, coupling, source_mosi_miso, source_sck, source_cs, level_mosi_miso, level_sck, level_cs, data, data_width, clk_slope, trigger_on, cs_idle, timeout):
+def spi(ctx, box, dut, mcu, mode, coupling, source_mosi_miso, source_sck, source_cs, level_mosi_miso, level_sck, level_cs, data, data_width, clk_slope, trigger_on, cs_idle, timeout):
     """
     Set SPI trigger
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -613,19 +617,19 @@ def cursor():
 
 @cursor.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
 @click.option('--x', required=False, type=click.FLOAT, help='cursor a x coordinate')
 @click.option('--y', required=False, type=click.FLOAT, help='cursor a y coordinate')
-def set_a(ctx, gateway, dut, mcu, x, y):
+def set_a(ctx, box, dut, mcu, x, y):
     """
         Set cursor a's x position
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -633,19 +637,19 @@ def set_a(ctx, gateway, dut, mcu, x, y):
 
 @cursor.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
 @click.option('--x', required=False, type=click.FLOAT, help='cursor b x coordinate')
 @click.option('--y', required=False, type=click.FLOAT, help='cursor b y coordinate')
-def set_b(ctx, gateway, dut, mcu, x, y):
+def set_b(ctx, box, dut, mcu, x, y):
     """
         Set cursor b's x position
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -653,19 +657,19 @@ def set_b(ctx, gateway, dut, mcu, x, y):
 
 @cursor.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
 @click.option('--del-x', required=False, type=click.FLOAT, help='shift a\'s x coordinate')
 @click.option('--del-y', required=False, type=click.FLOAT, help='shift a\'s y coordinate')
-def move_a(ctx, gateway, dut, mcu, del_x, del_y):
+def move_a(ctx, box, dut, mcu, del_x, del_y):
     """
         Shift cursor a's  position
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -673,19 +677,19 @@ def move_a(ctx, gateway, dut, mcu, del_x, del_y):
 
 @cursor.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
 @click.option('--del-x', required=False, type=click.FLOAT, help='shift b\'s x coordinate')
 @click.option('--del-y', required=False, type=click.FLOAT, help='shift b\'s y coordinate')
-def move_b(ctx, gateway, dut, mcu, del_x, del_y):
+def move_b(ctx, box, dut, mcu, del_x, del_y):
     """
         Shift cursor b's position
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
@@ -693,17 +697,17 @@ def move_b(ctx, gateway, dut, mcu, del_x, del_y):
 
 @cursor.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-@click.option('--dut', required=False, help='ID of DUT')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help='ID of DUT')
 @click.option('--mcu', required=False)
-def hide(ctx, gateway, dut, mcu):
+def hide(ctx, box, dut, mcu):
     """
         Hide cursor
     """
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, LOGIC_ROLE):
+    if not validate_net(ctx, box, netname, LOGIC_ROLE):
         click.secho(f"{netname} is not a logic net", fg="red", err=True)
         return
 
