@@ -209,17 +209,31 @@ def _resolve_dut(ctx: click.Context, dut_opt: Optional[str] = None) -> str:
                 click.echo("No DUTs are currently saved.", err=True)
 
             click.echo("", err=True)
-            click.echo("To add a new DUT, use:", err=True)
-            click.echo(f"  lager duts add --name {target_dut} --ip <IP_ADDRESS>", err=True)
+            click.echo("To add a new box, use:", err=True)
+            click.echo(f"  lager boxes add --name {target_dut} --ip <IP_ADDRESS>", err=True)
             ctx.exit(1)
 
     # get_default_gateway already handles local DUT resolution
     return get_default_gateway(ctx)
 
+def _natural_sort_key(text):
+    """
+    Convert a string into a list of mixed strings and integers for natural sorting.
+    This makes "adc2" come before "adc10" instead of alphabetical order.
+
+    Examples:
+        "adc1" -> ["adc", 1]
+        "adc10" -> ["adc", 10]
+        "uart2" -> ["uart", 2]
+    """
+    def atoi(s):
+        return int(s) if s.isdigit() else s
+    return [atoi(c) for c in re.split(r'(\d+)', text)]
+
 def _display_table(records):
 
-    # ----- sort records: first by net type, then by name -------------------------------------------------
-    sorted_records = sorted(records, key=lambda r: (r.get("role", ""), r.get("name", "")))
+    # ----- sort records: first by net type, then by name (with natural sorting) -------------------------
+    sorted_records = sorted(records, key=lambda r: (r.get("role", ""), _natural_sort_key(r.get("name", ""))))
 
     # ----- gather table data -------------------------------------------------
     headers = ["Name", "Net Type", "Instrument", "Channel", "Address"]
@@ -329,12 +343,16 @@ def _save_nets_batch(ctx: click.Context, dut: str, nets_data: List[dict]) -> Non
     invoke_without_command=True,
     help="List all saved nets.",
 )
-@click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 @click.pass_context
-def nets(ctx: click.Context, dut: str | None) -> None:  # noqa: D401
+def nets(ctx: click.Context, box: str | None, dut: str | None) -> None:  # noqa: D401
     """
     If no sub-command is supplied, default to "list".
     """
+    # Resolve box/dut (box takes precedence, dut is for backward compatibility)
+    dut = box or dut
+
     if ctx.invoked_subcommand is None:
         _list_nets(ctx, _resolve_dut(ctx, dut))
 
@@ -346,13 +364,16 @@ def nets(ctx: click.Context, dut: str | None) -> None:  # noqa: D401
 @nets.command("delete", help="Delete one saved net by name and type.")
 @click.argument("name")
 @click.argument("net_type")
-@click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 @click.option("--yes", is_flag=True, help="Skip confirmation prompt")
 @click.pass_context
 def delete_cmd(
-    ctx: click.Context, name: str, net_type: str, dut: str | None, yes: bool
+    ctx: click.Context, name: str, net_type: str, box: str | None, dut: str | None, yes: bool
 ) -> None:
-    dut = _resolve_dut(ctx, dut)
+    # Use box or dut (box takes precedence)
+    resolved = box or dut
+    dut = _resolve_dut(ctx, resolved)
     raw = _run_net_py(ctx, dut, "list")
     try:
         recs = _parse_backend_json(raw)
@@ -380,11 +401,16 @@ def delete_cmd(
 
 
 @nets.command("delete-all", help="Dangerous – delete every saved net.")
-@click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 @click.option("--yes", is_flag=True, help="Skip confirmation prompt")
 @click.pass_context
-def delete_all_cmd(ctx: click.Context, dut: str | None, yes: bool) -> None:
-    dut = _resolve_dut(ctx, dut)
+def delete_all_cmd(ctx: click.Context, box: str | None, dut: str | None, yes: bool) -> None:
+    # Use box or dut (box takes precedence)
+
+    resolved = box or dut
+
+    dut = _resolve_dut(ctx, resolved)
 
     if not yes and not click.confirm(
         f"Delete ALL saved nets on DUT {dut}? This cannot be undone."
@@ -397,14 +423,18 @@ def delete_all_cmd(ctx: click.Context, dut: str | None, yes: bool) -> None:
 
 
 @nets.command("tui", help="Launch the interactive Net-Manager TUI.")
-@click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 @click.pass_context
-def tui_cmd(ctx: click.Context, dut: str | None) -> None:
-    launch_tui(ctx, _resolve_dut(ctx, dut))
+def tui_cmd(ctx: click.Context, box: str | None, dut: str | None) -> None:
+    # Use box or dut (box takes precedence)
+    resolved = box or dut
+    launch_tui(ctx, _resolve_dut(ctx, resolved))
 
 
 # @nets.command("gui", help="Launch the interactive Net-Manager GUI.")
-# @click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 # @click.pass_context
 # def gui_cmd(ctx: click.Context, dut: str | None) -> None:
 #     # Import GUI module only when the command is actually used
@@ -420,18 +450,24 @@ def tui_cmd(ctx: click.Context, dut: str | None) -> None:
 @nets.command("rename", help="Rename a saved net.")
 @click.argument("name")
 @click.argument("new_name")
-@click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 @click.pass_context
 def rename_cmd(
     ctx: click.Context,
     name: str,
     new_name: str,
+    box: str | None,
     dut: str | None,
 ) -> None:
     """
     Rename a net. Prevent duplicate net names (regardless of type).
     """
-    dut = _resolve_dut(ctx, dut)
+    # Use box or dut (box takes precedence)
+
+    resolved = box or dut
+
+    dut = _resolve_dut(ctx, resolved)
 
     raw = _run_net_py(ctx, dut, "list")
     try:
@@ -467,10 +503,10 @@ def rename_cmd(
 @click.argument("role")
 @click.argument("channel")
 @click.argument("address")
-@click.option("--gateway")
+@click.option("--box")
 @click.option("--dut")
 @click.pass_context
-def create_cmd(ctx, name, role, channel, address, gateway, dut):
+def create_cmd(ctx, name, role, channel, address, box, dut):
     """
     Create a net using inferred instrument from VISA address.
 
@@ -482,9 +518,9 @@ def create_cmd(ctx, name, role, channel, address, gateway, dut):
     """
     from ..dut_storage import get_dut_ip
 
-    # Check if gateway is a local DUT name first
-    if gateway:
-        local_ip = get_dut_ip(gateway)
+    # Check if box is a local DUT name first
+    if box:
+        local_ip = get_dut_ip(box)
         if local_ip:
             gateway = local_ip
     elif dut:
@@ -674,15 +710,20 @@ def create_cmd(ctx, name, role, channel, address, gateway, dut):
 
 
 @nets.command("create-all", help="Create all possible nets that can be created on the DUT.")
-@click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 @click.option("--yes", is_flag=True, help="Skip confirmation prompt")
 @click.pass_context
-def create_all_cmd(ctx: click.Context, dut: str | None, yes: bool) -> None:
+def create_all_cmd(ctx: click.Context, box: str | None, dut: str | None, yes: bool) -> None:
     """
     Create all possible nets that can be created on a DUT.
     This command replicates the functionality of the 'Add Nets' page in the TUI.
     """
-    dut = _resolve_dut(ctx, dut)
+    # Use box or dut (box takes precedence)
+
+    resolved = box or dut
+
+    dut = _resolve_dut(ctx, resolved)
 
     def _run_and_json(script: str, *args: str) -> list:
         buf = io.StringIO()
@@ -892,9 +933,10 @@ def create_all_cmd(ctx: click.Context, dut: str | None, yes: bool) -> None:
 
 @nets.command("create-batch", help="Create multiple nets from a JSON file for better performance.")
 @click.argument("json_file", type=click.File("r"))
-@click.option("--dut", help="ID of DUT")
+@click.option("--box", help="Lagerbox name or IP")
+@click.option("--dut", hidden=True, help="Lagerbox name or IP")
 @click.pass_context
-def create_batch_cmd(ctx: click.Context, json_file, dut: str | None) -> None:
+def create_batch_cmd(ctx: click.Context, json_file, box: str | None, dut: str | None) -> None:
     """
     Create multiple nets from a JSON file containing an array of net definitions.
     
@@ -914,7 +956,11 @@ def create_batch_cmd(ctx: click.Context, json_file, dut: str | None) -> None:
         }
     ]
     """
-    dut = _resolve_dut(ctx, dut)
+    # Use box or dut (box takes precedence)
+
+    resolved = box or dut
+
+    dut = _resolve_dut(ctx, resolved)
 
     try:
         nets_data = json.load(json_file)
