@@ -43,7 +43,7 @@ def sigint_handler(kill_python, _sig, _frame):
     signal.signal(signal.SIGINT, _ORIGINAL_SIGINT_HANDLER)
     kill_python(signal.SIGINT)
 
-def _do_exit(exit_code, gateway, session, downloads):
+def _do_exit(exit_code, box, session, downloads):
     if exit_code == FAILED_TO_RETRIEVE_EXIT_CODE:
         click.secho('Failed to retrieve script exit code.', fg='red', err=True)
     elif exit_code == SIGTERM_EXIT_CODE:
@@ -65,10 +65,10 @@ def _do_exit(exit_code, gateway, session, downloads):
             click.secho(f'Failed to download {filename}: {exc}', fg='red', err=True)
     sys.exit(exit_code)
 
-def debug_tunnel(ctx, gateway):
+def debug_tunnel(ctx, box):
     host = 'localhost'
     port = 5555
-    connection_params = ctx.obj.websocket_connection_params(socktype='pdb', gateway_id=gateway)
+    connection_params = ctx.obj.websocket_connection_params(socktype='pdb', gateway_id=box)
     try:
         trio.run(serve_tunnel, host, port, connection_params, None)
     except PermissionError as exc:
@@ -108,18 +108,34 @@ def collect_output_callback(datatype, content, context):
         click.echo(content)
     return False, context
 
-def run_python_internal_get_output(ctx, runnable, gateway, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None):
-    return run_python_internal(ctx, runnable, gateway, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None, callback=collect_output_callback)
+def run_python_internal_get_output(ctx, runnable, box, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None):
+    return run_python_internal(ctx, runnable, box, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None, callback=collect_output_callback)
 
-def run_python_internal(ctx, runnable, gateway, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None, callback=None):
+def run_python_internal(ctx, runnable, box, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None, callback=None, dut_name=None):
     if extra_files is None:
         extra_files = []
 
-    # Use appropriate session based on whether gateway is an IP address
+    # Use appropriate session based on whether box is an IP address
+    gateway = box
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
-    session = ctx.obj.get_session_for_gateway(gateway)
+    # Auto-detect dut_name if not provided
+    # This allows username lookup to work even when commands don't explicitly pass dut_name
+    if dut_name is None and gateway:
+        from ..dut_storage import get_dut_ip, get_dut_name_by_ip
+
+        # Try forward lookup: is gateway a DUT name?
+        resolved_ip = get_dut_ip(gateway)
+        if resolved_ip:
+            dut_name = gateway  # Preserve the DUT name for username lookup
+            gateway = resolved_ip  # Use the IP for the session
+        else:
+            # Try reverse lookup: is gateway an IP with a saved DUT name?
+            dut_name = get_dut_name_by_ip(gateway)
+            # If found, dut_name is set; if not, it stays None (will use default username)
+
+    session = ctx.obj.get_session_for_gateway(gateway, dut_name=dut_name)
 
     if kill:
         signum = _get_signal_number(signum)
@@ -205,8 +221,8 @@ def run_python_internal(ctx, runnable, gateway, image, env, passenv, kill, downl
 @click.command()
 @click.pass_context
 @click.argument('runnable', required=False, type=click.Path(exists=True))
-@click.option('--gateway', required=False, help='DUT or Gateway IP', hidden=True)
-@click.option('--dut', required=False, help='DUT or Gateway IP')
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option('--dut', required=False, hidden=True, help="Lagerbox name or IP")
 @click.option('--image', default='lagerdata/gatewaypy3:v0.1.84', help='Docker image', show_default=True)
 @click.option(
     '--env',
@@ -224,13 +240,14 @@ def run_python_internal(ctx, runnable, gateway, image, env, passenv, kill, downl
 @click.option('--org', default=None, hidden=True)
 @click.option('--add-file', type=click.Path(exists=True, dir_okay=False), multiple=True, help='File to upload with script')
 @click.argument('args', nargs=-1)
-def python(ctx, runnable, gateway, dut, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, add_file, args):
+def python(ctx, runnable, box, dut, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, add_file, args):
     """Run Python script on gateway"""
     from ..dut_storage import get_dut_ip
 
-    # Check if gateway is a local DUT name first
-    if gateway:
-        local_ip = get_dut_ip(gateway)
+    # Check if box is a local DUT name first
+    gateway = box or dut
+    if box:
+        local_ip = get_dut_ip(box)
         if local_ip:
             gateway = local_ip
     elif dut:
@@ -300,7 +317,7 @@ def python(ctx, runnable, gateway, dut, image, env, passenv, kill, download, all
 #     signal.signal(signal.SIGINT, _ORIGINAL_SIGINT_HANDLER)
 #     kill_python(signal.SIGINT)
 
-# def _do_exit(exit_code, gateway, session, downloads):
+# def _do_exit(exit_code, box, session, downloads):
 #     if exit_code == FAILED_TO_RETRIEVE_EXIT_CODE:
 #         click.secho('Failed to retrieve script exit code.', fg='red', err=True)
 #     elif exit_code == SIGTERM_EXIT_CODE:
@@ -322,7 +339,7 @@ def python(ctx, runnable, gateway, dut, image, env, passenv, kill, download, all
 #             click.secho(f'Failed to download {filename}: {exc}', fg='red', err=True)
 #     sys.exit(exit_code)
 
-# def debug_tunnel(ctx, gateway):
+# def debug_tunnel(ctx, box):
 #     host = 'localhost'
 #     port = 5555
 #     connection_params = ctx.obj.websocket_connection_params(socktype='pdb', gateway_id=gateway)
@@ -365,10 +382,10 @@ def python(ctx, runnable, gateway, dut, image, env, passenv, kill, download, all
 #         click.echo(content)
 #     return False, context
 
-# def run_python_internal_get_output(ctx, runnable, gateway, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None):
+# def run_python_internal_get_output(ctx, runnable, box, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None):
 #     return run_python_internal(ctx, runnable, gateway, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None, callback=collect_output_callback)
 
-# def run_python_internal(ctx, runnable, gateway, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None, callback=None):
+# def run_python_internal(ctx, runnable, box, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, args, extra_files=None, callback=None):
 #     if extra_files is None:
 #         extra_files = []
 
@@ -460,8 +477,8 @@ def python(ctx, runnable, gateway, dut, image, env, passenv, kill, download, all
 # @click.command()
 # @click.pass_context
 # @click.argument('runnable', required=False, type=click.Path(exists=True))
-# @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
-# @click.option('--dut', required=False, help='ID of DUT')
+# @click.option("--box", required=False, help="Lagerbox name or IP")
+# @click.option('--dut', required=False, hidden=True, help='ID of DUT')
 # @click.option('--image', default='lagerdata/gatewaypy3:v0.1.84', help='Docker image to use for running script', show_default=True)
 # @click.option(
 #     '--env',
@@ -483,7 +500,7 @@ def python(ctx, runnable, gateway, dut, image, env, passenv, kill, download, all
 # @click.option('--org', default=None, hidden=True)
 # @click.option('--add-file', type=click.Path(exists=True, dir_okay=False), multiple=True, help='Add files to folder before upload')
 # @click.argument('args', nargs=-1)
-# def python(ctx, runnable, gateway, dut, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, add_file, args):
+# def python(ctx, runnable, box, dut, image, env, passenv, kill, download, allow_overwrite, signum, timeout, detach, port, org, add_file, args):
 #     """
 #         Run a python script on the gateway
 #     """
