@@ -9,7 +9,7 @@ from contextlib import redirect_stdout
 
 import click
 from texttable import Texttable
-from ..context import get_default_gateway, get_impl_path
+from ..context import get_default_gateway, get_impl_path, get_default_net
 from ..python.commands import run_python_internal
 
 SCOPE_ROLE = "scope"
@@ -28,12 +28,12 @@ def _require_netname(ctx) -> str:
     return netname
 
 
-def _resolve_gateway(ctx, gateway, dut):
+def _resolve_gateway(ctx, box, dut):
     from ..dut_storage import get_dut_ip
 
-    # Check if gateway is a local DUT name first
-    if gateway:
-        local_ip = get_dut_ip(gateway)
+    # Check if box is a local DUT name first
+    if box:
+        local_ip = get_dut_ip(box)
         if local_ip:
             return local_ip
 
@@ -43,7 +43,7 @@ def _resolve_gateway(ctx, gateway, dut):
         if local_ip:
             return local_ip
 
-    return gateway or dut or get_default_gateway(ctx)
+    return box or dut or get_default_gateway(ctx)
 
 
 def _run_net_py(ctx: click.Context, dut: str, *args: str) -> list[dict]:
@@ -76,21 +76,21 @@ def _run_net_py(ctx: click.Context, dut: str, *args: str) -> list[dict]:
         return []
 
 
-def _list_scope_nets(ctx, gateway):
-    recs = _run_net_py(ctx, gateway, "list")
+def _list_scope_nets(ctx, box):
+    recs = _run_net_py(ctx, box, "list")
     return [r for r in recs if r.get("role") == SCOPE_ROLE]
 
 
-def validate_net(ctx, gateway, netname, net_role):
+def validate_net(ctx, box, netname, net_role):
     """Validate that a net exists and has the specified role using locally saved nets"""
-    nets = _run_net_py(ctx, gateway, "list")
+    nets = _run_net_py(ctx, box, "list")
     for net in nets:
         if net.get("name") == netname and net.get("role") == net_role:
             return True
     return False
 
 
-def display_nets(ctx, gateway, netname: str | None):
+def display_nets(ctx, box, netname: str | None):
     table = Texttable()
     table.set_deco(Texttable.HEADER)
     table.set_cols_dtype(["t", "t", "t"])
@@ -136,29 +136,33 @@ def _run_backend(ctx, dut, action: str, **params):
 @click.group(invoke_without_command=True)
 @click.argument("NETNAME", required=False)
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
-def scope(ctx, gateway, dut, netname):
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
+def scope(ctx, box, dut, netname):
     """Control oscilloscope settings"""
+    # Use provided netname, or fall back to default if not provided
+    if netname is None:
+        netname = get_default_net(ctx, 'scope')
+
     if netname is not None:
         ctx.obj.netname = netname
 
     if ctx.invoked_subcommand is None:
-        gw = _resolve_gateway(ctx, gateway, dut)
+        gw = _resolve_gateway(ctx, box, dut)
         display_nets(ctx, gw, None)
 
 
 @scope.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
-def disable(ctx, gateway, dut, mcu):
+def disable(ctx, box, dut, mcu):
     """Disable scope channel"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -167,15 +171,15 @@ def disable(ctx, gateway, dut, mcu):
 
 @scope.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
-def enable(ctx, gateway, dut, mcu):
+def enable(ctx, box, dut, mcu):
     """Enable scope channel"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -184,15 +188,15 @@ def enable(ctx, gateway, dut, mcu):
 
 @scope.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
-def start(ctx, gateway, dut, mcu):
+def start(ctx, box, dut, mcu):
     """Start waveform capture"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -201,15 +205,15 @@ def start(ctx, gateway, dut, mcu):
 
 @scope.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
-def start_single(ctx, gateway, dut, mcu):
+def start_single(ctx, box, dut, mcu):
     """Start single waveform capture"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -218,15 +222,15 @@ def start_single(ctx, gateway, dut, mcu):
 
 @scope.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
-def stop(ctx, gateway, dut, mcu):
+def stop(ctx, box, dut, mcu):
     """Stop waveform capture"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -242,16 +246,16 @@ def measure():
 @measure.command()
 @click.pass_context
 @click.option("--mcu", required=False)
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--display", default=False, type=click.BOOL, help="Display measurement on screen")
 @click.option("--cursor", default=False, type=click.BOOL, help="Enable measurement cursor")
-def period(ctx, mcu, gateway, dut, display, cursor):
+def period(ctx, mcu, box, dut, display, cursor):
     """Measure waveform period"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -287,16 +291,16 @@ def period(ctx, mcu, gateway, dut, display, cursor):
 @measure.command()
 @click.pass_context
 @click.option("--mcu", required=False)
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--display", default=False, type=click.BOOL, help="Display measurement on screen")
 @click.option("--cursor", default=False, type=click.BOOL, help="Enable measurement cursor")
-def freq(ctx, mcu, gateway, dut, display, cursor):
+def freq(ctx, mcu, box, dut, display, cursor):
     """Measure waveform frequency"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -342,19 +346,19 @@ COUPLING_CHOICES = click.Choice(("dc", "ac", "low_freq_rej", "high_freq_rej"))
 @trigger.command()
 @click.pass_context
 @click.option("--mcu", required=False)
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mode", default="normal", type=MODE_CHOICES, help="Trigger mode", show_default=True)
 @click.option("--coupling", default="dc", type=COUPLING_CHOICES, help="Coupling mode", show_default=True)
 @click.option("--source", required=False, help="Trigger source", metavar="NET")
 @click.option("--slope", type=click.Choice(("rising", "falling", "both")), help="Trigger slope")
 @click.option("--level", type=click.FLOAT, help="Trigger level")
-def edge(ctx, mcu, gateway, dut, mode, coupling, source, slope, level):
+def edge(ctx, mcu, box, dut, mode, coupling, source, slope, level):
     """Set edge trigger"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -398,17 +402,17 @@ def cursor():
 
 @cursor.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
 @click.option("--x", required=False, type=click.FLOAT, help="Cursor A x coordinate")
 @click.option("--y", required=False, type=click.FLOAT, help="Cursor A y coordinate")
-def set_a(ctx, gateway, dut, mcu, x, y):
+def set_a(ctx, box, dut, mcu, x, y):
     """Set cursor A position"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -443,17 +447,17 @@ def set_a(ctx, gateway, dut, mcu, x, y):
 
 @cursor.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
 @click.option("--x", required=False, type=click.FLOAT, help="Cursor B x coordinate")
 @click.option("--y", required=False, type=click.FLOAT, help="Cursor B y coordinate")
-def set_b(ctx, gateway, dut, mcu, x, y):
+def set_b(ctx, box, dut, mcu, x, y):
     """Set cursor B position"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -488,17 +492,17 @@ def set_b(ctx, gateway, dut, mcu, x, y):
 
 @cursor.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
 @click.option("--del-x", required=False, type=click.FLOAT, help="Shift A x coordinate")
 @click.option("--del-y", required=False, type=click.FLOAT, help="Shift A y coordinate")
-def move_a(ctx, gateway, dut, mcu, del_x, del_y):
+def move_a(ctx, box, dut, mcu, del_x, del_y):
     """Shift cursor A position"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -533,17 +537,17 @@ def move_a(ctx, gateway, dut, mcu, del_x, del_y):
 
 @cursor.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
 @click.option("--del-x", required=False, type=click.FLOAT, help="Shift B x coordinate")
 @click.option("--del-y", required=False, type=click.FLOAT, help="Shift B y coordinate")
-def move_b(ctx, gateway, dut, mcu, del_x, del_y):
+def move_b(ctx, box, dut, mcu, del_x, del_y):
     """Shift cursor B position"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
@@ -578,15 +582,15 @@ def move_b(ctx, gateway, dut, mcu, del_x, del_y):
 
 @cursor.command()
 @click.pass_context
-@click.option("--gateway", required=False, help="DUT or Gateway IP", hidden=True)
-@click.option("--dut", required=False, help="DUT or Gateway IP")
+@click.option("--box", required=False, help="Lagerbox name or IP")
+@click.option("--dut", required=False, hidden=True, help="Lagerbox name or IP")
 @click.option("--mcu", required=False)
-def hide(ctx, gateway, dut, mcu):
+def hide(ctx, box, dut, mcu):
     """Hide cursor"""
-    gateway = _resolve_gateway(ctx, gateway, dut)
+    gateway = _resolve_gateway(ctx, box, dut)
     netname = _require_netname(ctx)
 
-    if not validate_net(ctx, gateway, netname, SCOPE_ROLE):
+    if not validate_net(ctx, box, netname, SCOPE_ROLE):
         click.secho(f"{netname} is not a scope net", fg="red", err=True)
         return
 
